@@ -41,7 +41,10 @@ mod imp {
     }
 
     impl ApplicationImpl for Application {
-        fn handle_local_options(&self, options: &glib::VariantDict) -> glib::ExitCode {
+        fn handle_local_options(
+            &self,
+            options: &glib::VariantDict,
+        ) -> std::ops::ControlFlow<glib::ExitCode> {
             let app = self.obj();
 
             if options.contains("new-window") {
@@ -51,7 +54,7 @@ mod imp {
 
                 if app.is_remote() {
                     app.activate_action("new-window", None);
-                    return glib::ExitCode::SUCCESS;
+                    return std::ops::ControlFlow::Break(glib::ExitCode::SUCCESS);
                 }
             }
 
