@@ -190,7 +190,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct Header(ObjectSubclass<imp::Header>)
-        @extends gtk::Widget;
+        @extends gtk::Widget,
+        @implements gtk::ConstraintTarget, gtk::Buildable, gtk::Accessible;
 }
 
 impl Header {
@@ -252,7 +253,7 @@ impl Header {
                         other_name
                             .split('.')
                             .next_back()
-                            .map(|last| format!(r#"<span size="x-small">{}</span>"#, last))
+                            .map(|last| format!(r#"<span size="x-small">{last}</span>"#))
                     }),
             );
             let text = lines.join("\n");
@@ -359,12 +360,12 @@ impl Header {
 
             imp.arrow.remove_css_class("expanded");
             imp.arrow.remove_css_class("accent");
-            imp.arrow.add_css_class("dim-label");
+            imp.arrow.add_css_class("dimmed");
         } else {
             animation.set_value_from(imp.default_height.get() as f64);
             animation.set_value_to(imp.expanded_height.get() as f64);
 
-            imp.arrow.remove_css_class("dim-label");
+            imp.arrow.remove_css_class("dimmed");
             imp.arrow.add_css_class("accent");
             imp.arrow.add_css_class("expanded");
         }
