@@ -89,7 +89,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct BusNameRow(ObjectSubclass<imp::BusNameRow>)
-        @extends gtk::Widget, gtk::ListBoxRow;
+        @extends gtk::Widget, gtk::ListBoxRow,
+        @implements gtk::ConstraintTarget, gtk::Buildable, gtk::Accessible, gtk::Actionable;
 }
 
 impl BusNameRow {
