@@ -6,6 +6,7 @@ mod application;
 mod config;
 mod bus_name_item;
 mod bus_name_list;
+mod busctl_cmd;
 mod color_widget;
 mod colors;
 mod details_view;
@@ -16,6 +17,7 @@ mod filtered_bus_name_model;
 mod filtered_message_model;
 mod i18n;
 mod message;
+mod message_fmt;
 mod message_list;
 mod message_tag;
 mod message_type;
@@ -39,6 +41,13 @@ use self::{
     config::{GETTEXT_PACKAGE, LOCALEDIR, RESOURCES_FILE},
 };
 
+#[derive(Debug, Clone)]
+pub enum ConnectionType {
+    Session,
+    System,
+    Address(String),
+}
+
 fn main() -> glib::ExitCode {
     // Initialize logger
     tracing_subscriber::fmt::init();
