@@ -47,7 +47,7 @@ impl fmt::Display for Cancelled {
 
 impl Cancelled {
     pub fn new(message: &str) -> Self {
-        Self(format!("Cancelled monitoring: {}", message))
+        Self(format!("Cancelled monitoring: {message}"))
     }
 }
 
