@@ -16,7 +16,7 @@ mod imp {
         pub(super) count: Cell<u32>,
         #[property(get, set, construct_only)]
         pub(super) total: Cell<u32>,
-        #[property(get, set, construct_only, builder(MessageType::default()))]
+        #[property(get, set, construct_only, default)]
         pub(super) message_type: Cell<MessageType>,
     }
 
