@@ -18,7 +18,7 @@ mod imp {
         pub(super) mean: Cell<u32>,
         #[property(get, set, construct_only)]
         pub(super) largest: Cell<u32>,
-        #[property(get, set, construct_only, builder(MessageType::default()))]
+        #[property(get, set, construct_only, default)]
         pub(super) message_type: OnceCell<MessageType>,
     }
 
