@@ -7,6 +7,7 @@ use gtk::{
 };
 
 use crate::{
+    ConnectionType,
     address_dialog::AddressDialog,
     application::Application,
     config::{APP_ID, PROFILE, VERSION},
@@ -115,7 +116,7 @@ mod imp {
             klass.bind_template();
             klass.bind_template_instance_callbacks();
 
-            klass.install_action("win.about", None, move |window, _, _| {
+            klass.install_action("win.about", None, |window, _, _| {
                 window.show_about_window();
             });
 
@@ -129,7 +130,7 @@ mod imp {
                     .set_show_sidebar(!imp.split_view_sub_page.shows_sidebar());
             });
 
-            klass.install_action_async("win.record-session-bus", None, |window, _, _| async move {
+            klass.install_action_async("win.record-session-bus", None, async |window, _, _| {
                 if let Err(err) = window
                     .start_recording(Monitor::session(), &gettext("Recording session bus…"))
                     .await
@@ -141,7 +142,7 @@ mod imp {
                 }
             });
 
-            klass.install_action_async("win.record-system-bus", None, |window, _, _| async move {
+            klass.install_action_async("win.record-system-bus", None, async |window, _, _| {
                 if let Err(err) = window
                     .start_recording(Monitor::system(), &gettext("Recording system bus…"))
                     .await
@@ -153,7 +154,7 @@ mod imp {
                 }
             });
 
-            klass.install_action_async("win.record-address", None, |window, _, _| async move {
+            klass.install_action_async("win.record-address", None, async |window, _, _| {
                 let Ok(address) = AddressDialog::choose(&window).await else {
                     return;
                 };
@@ -183,7 +184,7 @@ mod imp {
                 window.stop_recording();
             });
 
-            klass.install_action_async("win.open-log", None, |window, _, _| async move {
+            klass.install_action_async("win.open-log", None, async |window, _, _| {
                 if let Err(err) = window.open_log().await {
                     tracing::error!("Could not open log: {err:?}");
                     if !err
@@ -195,7 +196,7 @@ mod imp {
                 }
             });
 
-            klass.install_action_async("win.save", None, |window, _, _| async move {
+            klass.install_action_async("win.save", None, async |window, _, _| {
                 if let Err(err) = window.save().await {
                     tracing::error!("Could not save: {err:?}");
                     if !err
@@ -209,7 +210,7 @@ mod imp {
                 }
             });
 
-            klass.install_action_async("win.save-dot", None, |window, _, _| async move {
+            klass.install_action_async("win.save-dot", None, async |window, _, _| {
                 if let Err(err) = window.save_as_dot().await {
                     tracing::error!("Could not save: {err:?}");
                     if !err
@@ -271,7 +272,7 @@ mod imp {
 glib::wrapper! {
     pub struct Window(ObjectSubclass<imp::Window>)
         @extends gtk::Widget, gtk::Window, gtk::ApplicationWindow, adw::ApplicationWindow,
-        @implements gio::ActionMap, gio::ActionGroup, gtk::Root;
+        @implements gio::ActionMap, gio::ActionGroup, gtk::ConstraintTarget, gtk::Accessible, gtk::Buildable, gtk::ShortcutManager, gtk::Native, gtk::Root;
 }
 
 impl Window {
@@ -409,7 +410,7 @@ impl Window {
             .application_icon(APP_ID)
             .copyright("© 2008–2023 Will Thompson, Collabora Ltd. and contributors")
             .license_type(gtk::License::Lgpl21)
-            .website("https://gitlab.gnome.org/World/bustle")
+            .website("https://apps.gnome.org/Bustle/")
             .version(VERSION)
             .translator_credits(gettext("translator-credits"))
             .developer_name(gettext("The Bustle developers"))
@@ -542,7 +543,7 @@ impl Window {
             .filters(&filters)
             .modal(true);
         if let Some(filename) = imp.filename.borrow().as_ref() {
-            builder = builder.initial_name(format!("{}.pcap", filename));
+            builder = builder.initial_name(format!("{filename}.pcap"));
         }
         let chooser = builder.build();
 
@@ -576,7 +577,7 @@ impl Window {
             .filters(&filters)
             .modal(true);
         if let Some(filename) = imp.filename.borrow().as_ref() {
-            builder = builder.initial_name(format!("{}.gv", filename));
+            builder = builder.initial_name(format!("{filename}.gv"));
         }
         let chooser = builder.build();
 
@@ -590,7 +591,7 @@ impl Window {
         Ok(())
     }
 
-    fn add_message_toast(&self, message: &str) {
+    pub fn add_message_toast(&self, message: &str) {
         let toast = adw::Toast::new(message);
         self.imp().toast_overlay.add_toast(toast);
     }
@@ -653,6 +654,15 @@ impl Window {
         }
     }
 
+    pub fn connection_type(&self) -> Option<ConnectionType> {
+        self.imp()
+            .monitor
+            .borrow()
+            .as_ref()
+            .map(|m| m.connection_type())
+            .cloned()
+    }
+
     #[template_callback]
     fn copy_command_clicked(&self) {
         const CMD: &str = "dbus-monitor --pcap";
